@@ -1,7 +1,7 @@
 //! This crate provides the [`ReflectMessage`](https://docs.rs/prost-reflect/latest/prost_reflect/derive.ReflectMessage.html) derive macro
 //!
 //! For documentation, see the example in the [`prost-reflect` crate docs](https://docs.rs/prost-reflect/latest/prost_reflect/index.html#deriving-reflectmessage).
-#![doc(html_root_url = "https://docs.rs/prost-reflect-derive/0.6.0/")]
+#![doc(html_root_url = "https://docs.rs/prost-reflect-derive/0.6.1/")]
 
 use proc_macro::TokenStream;
 use proc_macro2::Span;
@@ -45,7 +45,7 @@ fn reflect_message_impl(input: syn::DeriveInput) -> Result<proc_macro2::TokenStr
             fn descriptor(&self) -> ::prost_reflect::MessageDescriptor {
                 #file_descriptor_set
                     .get_message_by_name(#message_name)
-                    .expect("no message found")
+                    .expect(concat!("descriptor for message type `", #message_name, "` not found"))
             }
         }
     })
